Tests
=====

To run any of the tests copy the contents of ``database.cfg.example`` into
a new file called ``database.cfg`` and adjust the settings to your needs.

Then run one of the following tests:

- ``async_client.py``
- ``adisp_client.py``
- ``blocking_client.py``

Or run ``runtests.py`` to run all tests.
